Module hooks

Module hooks 

Macros

global
Can be used to create a GlobalSignal, a global Calculated or a global Effect.

Structs

Calculated
Context
Effect
Runs always on creation and on every updated of the readed signals
GlobalSignal
GlobalWrapper
QuerySignal
Signal
StorageSignal

Traits

SignalBase
SignalGetter
SignalSetter
SignalToggle
SignalUpdater

Functions

spawn
Runs the provided future.
spawn_result
timeout
Creates a timeout for the specified number of milliseconds. This runs asynchronously and therefore does not block any thread.