timeout

Function timeout 

pub async fn timeout(ms: u16) -> Result<()>
Creates a timeout for the specified number of milliseconds. This runs asynchronously and therefore does not block any thread.

A timeout is cancelled when the scope in which it was created goes out of scope. In this case, any calls after the timeout will not be made.