GlobalSignal

Struct GlobalSignal 

pub struct GlobalSignal<T>(/* private fields */);

Implementations

Source

impl<T> GlobalSignal<T>
where T: 'static,

pub fn new(initial: T) -> Self

Will not be removed when the component which created it goes out of scope.

This is useful for signals that should be globally accessible.