pub struct GlobalWrapper<S: 'static> { /* private fields */ }Trait Implementations
Sourceimpl<S: Clone + 'static> Clone for GlobalWrapper<S>
impl<S: Clone + 'static> Clone for GlobalWrapper<S>
Sourcefn clone(&self) -> GlobalWrapper<S>
fn clone(&self) -> GlobalWrapper<S>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<S: Debug + 'static> Debug for GlobalWrapper<S>
impl<S: Debug + 'static> Debug for GlobalWrapper<S>
Sourceimpl<S, T> From<GlobalWrapper<S>> for Signal<T>
impl<S, T> From<GlobalWrapper<S>> for Signal<T>
Sourcefn from(val: GlobalWrapper<S>) -> Self
fn from(val: GlobalWrapper<S>) -> Self
Converts to this type from the input type.
Sourceimpl<S, T> SignalBase<T> for GlobalWrapper<S>where
S: SignalBase<T>,
impl<S, T> SignalBase<T> for GlobalWrapper<S>where
S: SignalBase<T>,
Sourceimpl<S, T> SignalGetter<T> for GlobalWrapper<S>where
S: SignalGetter<T>,
T: Clone + 'static,
impl<S, T> SignalGetter<T> for GlobalWrapper<S>where
S: SignalGetter<T>,
T: Clone + 'static,
Sourceimpl<S, T> SignalSetter<T> for GlobalWrapper<S>
impl<S, T> SignalSetter<T> for GlobalWrapper<S>
Sourceimpl<S, T> SignalUpdater<T> for GlobalWrapper<S>where
S: Copy + SignalUpdater<T>,
T: 'static,
impl<S, T> SignalUpdater<T> for GlobalWrapper<S>where
S: Copy + SignalUpdater<T>,
T: 'static,
Sourcefn update<U>(&self, updater: impl FnOnce(&mut T) -> U) -> U
fn update<U>(&self, updater: impl FnOnce(&mut T) -> U) -> U
Updates the signal value without cloning it using the provided updater function and notifies all dependencies.
This will happen, no matter if the value acually changed or not. Read more
Sourcefn set_unchecked(&self, value: impl Into<T>)
fn set_unchecked(&self, value: impl Into<T>)
Sets the value of the signal and notifies all its dependencies. Read more
impl Collect for GlobalWrapper<Effect>
impl<S: Copy + 'static> Copy for GlobalWrapper<S>