Signal

Struct Signal 

pub struct Signal<T> { /* private fields */ }

Implementations

Source

impl<T> Signal<T>
where T: 'static,

pub fn new(initial: T) -> Self

Creates a new signal with the given initial value.

A signal is a reactive value that can be read and updated. When a signal is updated, all function components that read the signal will be re-run to reflect the new value.

The signal is removed when the component which created it goes out of scope.

Example
use rustolio_web::prelude::*;

let s = Signal::new("Hello World".to_string());
div! {
    class: "container",
    move || s.value(),
};
Caveats

All caveats will throw an runtime error in debug mode.

Immutable Signals

When creating a signal, it is important to ensure that the signal is read in a function component (e.g., move || s.value()). If this is not done, the signal itself will be recreated on every update, making it effectively immutable.

Dont do this:

use rustolio_web::prelude::*;

let s = Signal::new("Hello World".to_string());
div! {
   s.value()
};

Do this instead:

use rustolio_web::prelude::*;

let s = Signal::new("Hello World".to_string());
div! {
   move || s.value()
};
// OR
move || div! {
   s.value()
};
Breaking Signals

When reading a signal value, it is important to ensure that the next component is not a function component. This would break the signal’s updater, as it would replace the component without notifying the signal’s updater.

Dont do this:

use rustolio_web::prelude::*;

let s = Signal::new("Hello World".to_string());
let s1 = Signal::new("Hello World 2".to_string());
div! {
   move || {
      let value = s.value();
      move || div! {
         format!("S: {} - S1: {}", value, s1.value())
      }
   }
};

Do this instead:

use rustolio_web::prelude::*;

let s = Signal::new("Hello World".to_string());
let s1 = Signal::new("Hello World 2".to_string());
div! {
   move || {
      let value = s.value();
      div! {
         move || div! {
            format!("S: {} - S1: {}", value, s1.value())
         }
      }
   }
};
pub fn always_mutable(initial: T) -> Self

Creates the Signal (same as Self::new) but the check for immutablility will alway succeed.

This can be useful for Signal-Wrapper which are allowed the be read in the same scope.