pub trait SignalBase<T> { // Required method fn base(&self) -> Signal<T>; }
Returns the underlying signal of the concrete implementation.
This is used the implement all other common signal methods, but can be useful to “flatten” other Hooks so they can be used as a “standard” signal