SignalSetter

Trait SignalSetter 

pub trait SignalSetter<T>: SignalBase<T>
where T: PartialEq + 'static,
{ // Provided method fn set(&self, value: impl Into<T>) -> T { ... } }

Provided Methods

fn set(&self, value: impl Into<T>) -> T

Sets the value of the signal and notifies all dependencies.

If the value is the same as the current value, nothing happens.

Returns the old value of the signal.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<S, T> SignalSetter<T> for GlobalWrapper<S>
where S: Copy + SignalSetter<T>, T: PartialEq + 'static,

Source

impl<T> SignalSetter<T> for Context<T>
where T: PartialEq + 'static,

Source

impl<T> SignalSetter<T> for GlobalSignal<T>
where T: PartialEq + 'static,

Source

impl<T> SignalSetter<T> for QuerySignal<T>
where T: PartialEq + 'static,

Source

impl<T> SignalSetter<T> for Signal<T>
where T: PartialEq + 'static,

Source

impl<T> SignalSetter<T> for StorageSignal<T>
where T: PartialEq + 'static,