pub trait SignalGetter<T>: SignalBase<T>where
T: Clone + 'static,{
// Provided methods
fn peek(&self) -> T { ... }
fn value(&self) -> T { ... }
}Provided Methods
Sourcefn peek(&self) -> T
fn peek(&self) -> T
Returns the current value of the signal without tracking updates.
If updates should be tracked, use Self::value().
Sourcefn value(&self) -> T
fn value(&self) -> T
Return the value of the signal and appends it to the current scope’s dependencies. If the values changes, the scope gets reexecuted to update to the new value.
If update should not be tracked, use Self::peek().